"""Colors.

This module contain Colors enum.
"""

from enum import StrEnum


class Colors(StrEnum):
    BLUE = "b"
    RED = "r"
    GREEN = "g"
    CEAN = "c"
    MAGENTA = "m"
    YELLOW = "y"
    BLACK = "k"
    ROYALBLUE = "royalblue"
    STEELBLUE = "steelblue"
    DIMGRAY = "dimgray"
    CORNFLOWERBLUE = "cornflowerblue"
